/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */



#ifndef SBK_QTHELP_PYTHON_H
#define SBK_QTHELP_PYTHON_H

//workaround to access protected functions
#define protected public

#include <Python.h>
#include <conversions.h>
#include <pyenum.h>
#include <basewrapper.h>
#include <bindingmanager.h>
#include <memory>

#include <qsignal.h>
// Module Includes
#include <pyside_qtgui_python.h>
#include <pyside_qtcore_python.h>

// Binded library includes
#include <qhelpsearchresultwidget.h>
#include <qhelpsearchengine.h>
#include <qhelpindexwidget.h>
#include <qhelpsearchquerywidget.h>
#include <qhelpcontentwidget.h>
#include <qhelpenginecore.h>
#include <qhelpengine.h>
// Conversion Includes - Primitive Types
#include <QString>
#include <signalmanager.h>
#include <typeresolver.h>
#include <QTextDocument>
#include <QtConcurrentFilter>

// Conversion Includes - Container Types
#include <QMap>
#include <QStack>
#include <QVector>
#include <QStringList>
#include <QSet>
#include <QPair>
#include <pysideconversions.h>
#include <qqueue.h>
#include <QList>
#include <QMultiMap>

// Type indices
#define SBK_QHELPSEARCHQUERY_IDX                                     0
#define SBK_QHELPSEARCHQUERY_FIELDNAME_IDX                           1
#define SBK_QHELPCONTENTITEM_IDX                                     2
#define SBK_QHELPINDEXMODEL_IDX                                      3
#define SBK_QHELPCONTENTMODEL_IDX                                    4
#define SBK_QHELPSEARCHRESULTWIDGET_IDX                              5
#define SBK_QHELPSEARCHQUERYWIDGET_IDX                               6
#define SBK_QHELPINDEXWIDGET_IDX                                     7
#define SBK_QHELPCONTENTWIDGET_IDX                                   8
#define SBK_QHELPSEARCHENGINE_IDX                                    9
#define SBK_QHELPENGINECORE_IDX                                      10
#define SBK_QHELPENGINE_IDX                                          11
#define SBK_QtHelp_IDX_COUNT                                         12

// This variable stores all python types exported by this module
extern PyTypeObject** SbkPySide_QtHelpTypes;

// Macros for type check

namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject* SbkType<QHelpSearchQuery::FieldName >() { return SbkPySide_QtHelpTypes[SBK_QHELPSEARCHQUERY_FIELDNAME_IDX]; }
template<> inline PyTypeObject* SbkType<QHelpSearchQuery >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPSEARCHQUERY_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpContentItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPCONTENTITEM_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpIndexModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPINDEXMODEL_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpContentModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPCONTENTMODEL_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpSearchResultWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPSEARCHRESULTWIDGET_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpSearchQueryWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPSEARCHQUERYWIDGET_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpIndexWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPINDEXWIDGET_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpContentWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPCONTENTWIDGET_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpSearchEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPSEARCHENGINE_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpEngineCore >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPENGINECORE_IDX]); }
template<> inline PyTypeObject* SbkType<QHelpEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide_QtHelpTypes[SBK_QHELPENGINE_IDX]); }

template<>
inline PyObject* createWrapper<QHelpIndexModel >(const QHelpIndexModel* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpIndexModel >()),const_cast<QHelpIndexModel*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHelpContentModel >(const QHelpContentModel* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpContentModel >()),const_cast<QHelpContentModel*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHelpSearchResultWidget >(const QHelpSearchResultWidget* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpSearchResultWidget >()),const_cast<QHelpSearchResultWidget*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHelpSearchQueryWidget >(const QHelpSearchQueryWidget* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpSearchQueryWidget >()),const_cast<QHelpSearchQueryWidget*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHelpIndexWidget >(const QHelpIndexWidget* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpIndexWidget >()),const_cast<QHelpIndexWidget*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHelpContentWidget >(const QHelpContentWidget* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpContentWidget >()),const_cast<QHelpContentWidget*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHelpSearchEngine >(const QHelpSearchEngine* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpSearchEngine >()),const_cast<QHelpSearchEngine*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHelpEngineCore >(const QHelpEngineCore* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpEngineCore >()),const_cast<QHelpEngineCore*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
template<>
inline PyObject* createWrapper<QHelpEngine >(const QHelpEngine* cppobj, bool hasOwnership, bool isExactType)
{
    PyObject* pyObj = Shiboken::SbkBaseWrapper_New(reinterpret_cast<SbkBaseWrapperType*>(SbkType<QHelpEngine >()),const_cast<QHelpEngine*>(cppobj), hasOwnership, isExactType);
    PySide::signalUpdateSource(pyObj);
    return pyObj;
}
// Generated converters declarations ----------------------------------

template<>
struct Converter<QHelpSearchQuery::FieldName > : EnumConverter<QHelpSearchQuery::FieldName >
{
};

template<>
struct Converter<QHelpSearchQuery > : ValueTypeConverter<QHelpSearchQuery >
{
};

template<>
struct Converter<QHelpContentItem > : ValueTypeConverter<QHelpContentItem >
{
};

template<>
struct Converter<QHelpIndexModel* > : ObjectTypeConverter<QHelpIndexModel >
{
};

template<>
struct Converter<QHelpIndexModel& > : ObjectTypeReferenceConverter<QHelpIndexModel >
{
};

template<>
struct Converter<QHelpContentModel* > : ObjectTypeConverter<QHelpContentModel >
{
};

template<>
struct Converter<QHelpContentModel& > : ObjectTypeReferenceConverter<QHelpContentModel >
{
};

template<>
struct Converter<QHelpSearchResultWidget* > : ObjectTypeConverter<QHelpSearchResultWidget >
{
};

template<>
struct Converter<QHelpSearchResultWidget& > : ObjectTypeReferenceConverter<QHelpSearchResultWidget >
{
};

template<>
struct Converter<QHelpSearchQueryWidget* > : ObjectTypeConverter<QHelpSearchQueryWidget >
{
};

template<>
struct Converter<QHelpSearchQueryWidget& > : ObjectTypeReferenceConverter<QHelpSearchQueryWidget >
{
};

template<>
struct Converter<QHelpIndexWidget* > : ObjectTypeConverter<QHelpIndexWidget >
{
};

template<>
struct Converter<QHelpIndexWidget& > : ObjectTypeReferenceConverter<QHelpIndexWidget >
{
};

template<>
struct Converter<QHelpContentWidget* > : ObjectTypeConverter<QHelpContentWidget >
{
};

template<>
struct Converter<QHelpContentWidget& > : ObjectTypeReferenceConverter<QHelpContentWidget >
{
};

template<>
struct Converter<QHelpSearchEngine* > : ObjectTypeConverter<QHelpSearchEngine >
{
};

template<>
struct Converter<QHelpSearchEngine& > : ObjectTypeReferenceConverter<QHelpSearchEngine >
{
};

template<>
struct Converter<QHelpEngineCore* > : ObjectTypeConverter<QHelpEngineCore >
{
};

template<>
struct Converter<QHelpEngineCore& > : ObjectTypeReferenceConverter<QHelpEngineCore >
{
};

template<>
struct Converter<QHelpEngine* > : ObjectTypeConverter<QHelpEngine >
{
};

template<>
struct Converter<QHelpEngine& > : ObjectTypeReferenceConverter<QHelpEngine >
{
};

} // namespace Shiboken

// User defined converters --------------------------------------------
// Generated converters implemantations -------------------------------


#endif // SBK_QTHELP_PYTHON_H

